@@ -2,11 +2,14 @@
 import argparse
 
 from dominate.tags import p
+import numpy as np
 import pandas as pd
 from pkg_resources import resource_filename
 
 import ezcharts as ezc
+from ezcharts import util
 from ezcharts.components.ezchart import EZChart
+from ezcharts.components.fastcat import SeqSummary
 from ezcharts.components.nextclade import NextClade, NXTComponent
 from ezcharts.components.reports.labs import LabsReport
 from ezcharts.components.theme import LAB_head_resources
@@ -15,7 +18,7 @@ from ezcharts.layout.snippets import Stats
 from ezcharts.layout.snippets import Tabs
 from ezcharts.layout.snippets.cards import Cards, ICard
 from ezcharts.layout.snippets.progress import Progress
-from ezcharts.plots import Plot, util
+from ezcharts.plots import Plot
 from ezcharts.plots.ideogram import ideogram
 
 # Setup simple globals
@@ -25,8 +28,7 @@ REPORT_TITLE = f'{WORKFLOW_NAME}-report'
 
 def main(args):
     """Demo for ezCharts functionality."""
-    util.set_basic_logging()
-    logger = util.get_named_logger("ezCharts Demo")
+    logger = util.get_named_logger("ezChrtDemo")
 
     # Good location to prepare plots
     logger.info('Building plots')
@@ -49,6 +51,11 @@ def main(args):
             plot = ezc.lineplot(data=df, x='year', y='sales', hue='product')
         elif style == "scatter":
             plot = ezc.scatterplot(data=df, x='year', y='sales', hue='product')
+        elif style == 'histogram':
+            plot = ezc.histplot(
+                data=np.random.randint(0, 11, size=1000), bins=10)
+        elif style == "bar":
+            plot = ezc.barplot(data=df, x='year', y='sales', hue='product')
         else:
             raise ValueError("Unknown plot style")
         plot.title = {"text": f"Example {style} chart"}
@@ -61,6 +68,8 @@ def main(args):
     params = resource_filename('ezcharts', "data/test/params.json")
     versions = resource_filename('ezcharts', "data/test/versions.txt")
     nxt_json = resource_filename('ezcharts', "data/test/nextclade.json")
+    fastcat_results = resource_filename(
+        'ezcharts', "data/test/fastcat.stats.gz")
 
     # Create report
     # Note we need to add nextclade as a resource
@@ -94,6 +103,10 @@ def main(args):
                 ('10213 bp', 'Some other stat')
             ])
 
+    # Add sequence summary component
+    with report.add_section('Sequence summaries', 'Summaries'):
+        SeqSummary(fastcat_results)
+
     # This also adds to main_content, but provides a nice
     # container snippet as a starting context.
     with report.add_section('Controls', 'Controls'):
@@ -123,6 +136,8 @@ def main(args):
             with Grid():
                 EZChart(example_plot("line"), 'epi2melabs')
                 EZChart(example_plot("scatter"), 'epi2melabs')
+                EZChart(example_plot("bar"), 'epi2melabs')
+                EZChart(example_plot("histogram"), 'epi2melabs')
         with tabs.add_tab('Accuracy', False):
             p("This is a mixed tab!")
             EZChart(example_plot(), 'epi2melabs')
